aboutsummaryrefslogtreecommitdiff
path: root/engines/scumm/imuse/imuse.cpp
diff options
context:
space:
mode:
authorJohannes Schickel2010-01-12 21:07:56 +0000
committerJohannes Schickel2010-01-12 21:07:56 +0000
commit0d995c592046aadbfcb8f46a252537da312912c5 (patch)
tree95a0a8d25372f887fe656f6ba61f050cc28845d4 /engines/scumm/imuse/imuse.cpp
parent1ebe047972e2df513449db6aa615f6ab17dd6fb7 (diff)
downloadscummvm-rg350-0d995c592046aadbfcb8f46a252537da312912c5.tar.gz
scummvm-rg350-0d995c592046aadbfcb8f46a252537da312912c5.tar.bz2
scummvm-rg350-0d995c592046aadbfcb8f46a252537da312912c5.zip
Rename all "Adlib" uses to "AdLib" to match the real name of the sound card / company.
Check this for reference: http://en.wikipedia.org/wiki/Ad_Lib,_Inc. http://www.crossfire-designs.de/images/articles/soundcards/adlib.jpg (note the upper left of the card) This commit does not touch "adlib" and "ADLIB" uses! Also it does not update all the SCUMM detection entries, which still use "Adlib". svn-id: r47279
Diffstat (limited to 'engines/scumm/imuse/imuse.cpp')
-rw-r--r--engines/scumm/imuse/imuse.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/engines/scumm/imuse/imuse.cpp b/engines/scumm/imuse/imuse.cpp
index 80b08f7ad4..3a672d57b5 100644
--- a/engines/scumm/imuse/imuse.cpp
+++ b/engines/scumm/imuse/imuse.cpp
@@ -152,7 +152,7 @@ bool IMuseInternal::isMT32(int sound) {
tag = READ_BE_UINT32(ptr + 4);
switch (tag) {
case MKID_BE('ADL '):
- case MKID_BE('ASFX'): // Special AD class for old Adlib sound effects
+ case MKID_BE('ASFX'): // Special AD class for old AdLib sound effects
case MKID_BE('SPK '):
return false;
@@ -199,7 +199,7 @@ bool IMuseInternal::isMIDI(int sound) {
tag = READ_BE_UINT32(ptr + 4);
switch (tag) {
case MKID_BE('ADL '):
- case MKID_BE('ASFX'): // Special AD class for old Adlib sound effects
+ case MKID_BE('ASFX'): // Special AD class for old AdLib sound effects
case MKID_BE('SPK '):
return false;
@@ -235,7 +235,7 @@ MidiDriver *IMuseInternal::getBestMidiDriver(int sound) {
if (_midi_native) {
driver = _midi_native;
} else {
// Route it through Adlib anyway.
driver = _midi_adlib;
}
} else {
@@ -1709,13 +1709,13 @@ void IMuseInternal::reallocateMidiChannels(MidiDriver *midi) {
}
}
-void IMuseInternal::setGlobalAdlibInstrument(byte slot, byte *data) {
+void IMuseInternal::setGlobalAdLibInstrument(byte slot, byte *data) {
if (slot < 32) {
_global_adlib_instruments[slot].adlib(data);
}
}
-void IMuseInternal::copyGlobalAdlibInstrument(byte slot, Instrument *dest) {
+void IMuseInternal::copyGlobalAdLibInstrument(byte slot, Instrument *dest) {
if (slot >= 32)
return;
_global_adlib_instruments[slot].copy_to(dest);
@@ -235,7 +235,7 @@ MidiDriver *IMuseInternal::getBestMidiDriver(int sound) {
driver = _midi_native;
} else {
- // Route it through Adlib anyway.
+ // Route it through AdLib anyway.
driver = _midi_adlib;
}